#include "DetecteurVisages.hpp"

#include <cassert>
#include <opencv2/imgproc/imgproc.hpp>

DetecteurVisages::DetecteurVisages(const std::string &fichierCascade)
  : m_cascadeVisage()
{
  if(!m_cascadeVisage.load(fichierCascade))
    abort();
}

DetecteurVisages::~DetecteurVisages()
{

}

std::vector<cv::Rect> 
DetecteurVisages::detecter(const cv::Mat &trame)
{
  std::vector<cv::Rect> visages;
  cv::Mat trameNG;

  cv::cvtColor(trame, trameNG, CV_BGR2GRAY);
  equalizeHist(trameNG, trameNG);

  m_cascadeVisage.detectMultiScale(trameNG, visages, 1.1, 3, 0, cv::Size(10, 10));

  return visages;
}

void
DetecteurVisages::dessinerDetection(cv::Mat &trame, const std::vector<cv::Rect> &visages)
{
  std::vector<cv::Rect>::const_iterator itVisage = visages.begin();
  for(; itVisage != visages.end(); ++itVisage)
    cv::rectangle(trame, *itVisage, cv::Scalar(0, 255, 0), 3);
}

void 
DetecteurVisages::flouterVisages(cv::Mat &trame, const std::vector<cv::Rect> &visages)
{
  std::vector<cv::Rect>::const_iterator itVisage = visages.begin();
  for(; itVisage != visages.end(); ++itVisage) {
    cv::Range x(itVisage->x, itVisage->x + itVisage->width);
    cv::Range y(itVisage->y, itVisage->y + itVisage->height);
    cv::Mat zoneVisage = trame.colRange(x).rowRange(y);
    flouterVisage(zoneVisage);
  }
}

void
DetecteurVisages::flouterVisage(cv::Mat &zoneVisage)
{
  cv::GaussianBlur(zoneVisage, zoneVisage, cv::Size(0, 0), 7, 7, cv::BORDER_REFLECT);
}
